#!/bin/bash
# Based on slackbuilds by Borromini, Zeqadious, rhys_rhaven
#
# maintainer       : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# former           : guth guth-at-ploposor.com
# homepage         : http://download.aircrack-ng.org/aircrack-ng-${VERSION}.tar.gz
# depends          : 

#Build time variables needed to make the package
PKG_NAME="aircrack-ng"
VERSION="1.1"
VERSION_FILE="1.1"
ARCH="i486"     #i486
CPU="i686"      #i686
ZEN_VER="66.1"

#Location variables on making the package
SRC_URL="http://download.aircrack-ng.org/aircrack-ng-${VERSION_FILE}.tar.gz"
EXTENSION="tar.gz"
MAKEJOBS="2" #2 is light, 6 is heavy
CWD="`pwd`"
TMP="${CWD}/${PKG_NAME}-${VERSION_FILE}"
PKG="${CWD}/build"

# make sure we're root
if [ ${UID} != "0" ]; then
	echo "This script must be run as root!"
	exit
fi 

# display help section
if [ "${1}" = "--help" ]; then	
	echo \
	"Zenwalk ${0} script:
			--nocleanup	Do NOT Cleanup of Post build and Temporary Repo
			--help		Displays this help"
	exit
fi

# to set the --nocleanup option from the command line
if [ "${1}" = "--nocleanup" ]; then
	CLEANUP="0"
else
	CLEANUP="1"
fi

# make the package building directory and clean any old ones out
echo "cleaning build environment"
if [ -d ${PKG} ]; then 
	rm -rf ${PKG}
fi
	mkdir -p ${PKG}

# First we need to find the source
if [ -f ${CWD}/${PKG_NAME}-${VERSION_FILE}.${EXTENSION} ]; then
	echo "Source present, not downloading" 
else
	 wget ${SRC_URL} 
fi

if [ ! -f ${CWD}/${PKG_NAME}-${VERSION_FILE}.${EXTENSION} ]; then
  echo "ERROR: Source cannot be downloaded"
  exit 1
fi

# Now we extract the source
if [ ${EXTENSION} = tar.gz ]; then
	tar -xzvf ${CWD}/${PKG_NAME}-${VERSION_FILE}.${EXTENSION}
fi

if [ ${EXTENSION} = tar.bz2 ]; then
	tar -xjvf ${CWD}/${PKG_NAME}-${VERSION_FILE}.${EXTENSION}
fi

if [ ! -d ${CWD}/${PKG_NAME}-${VERSION_FILE} ]; then
  echo "ERROR: Source cannot be extracted"
  exit 1
fi

# Configure the package to be compiled
cd ${TMP}

export CFLAGS="-O2 -march=${ARCH} -mtune=${CPU}"
export CXXFLAGS="-O2 -march=${ARCH} -mtune=${CPU}"

# make and install the package  
make -j${MAKEJOBS}

make prefix=/usr destdir=${PKG} DESTDIR=${PKG} install

# Copy and compress documentation
install -d -m755 -p ${PKG}/usr/doc/${PKG_NAME}-${VERSION}
install -v -m644  \
  {README,INSTALLING,AUTHORS,VERSION,ChangeLog,LICENSE} \
  ${PKG}/usr/doc/${PKG_NAME}-${VERSION} 2> /dev/null
  
rm -rf ${PKG}/usr/doc/${PKG_NAME} 2> /dev/null

gzip -9 ${PKG}/usr/info/* 2> /dev/null
gzip -9 ${PKG}/usr/man/*/* 2> /dev/null
gzip -9 ${PKG}/usr/man/*/*/* 2> /dev/null

# strip the files!
cd ${PKG}

find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
find . | xargs file | grep "current ar archive" | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Create slack-desc
install -d -m755 ${PKG}/install
cat > ${PKG}/install/slack-desc << END
           |-handy-ruler------------------------------------------------------|
aircrack-ng: $NAME $PROGRAM_VER (WLAN tools for breaking 802.11 WEP/WPA keys)
aircrack-ng:
aircrack-ng: aircrack-ng is a set of tools for auditing wireless networks.
aircrack-ng: It's an enhanced/reborn version of aircrack.
aircrack-ng: It consists of airodump-ng (an 802.11 packet capture program),
aircrack-ng: aireplay-ng (an 802.11 packet injection program),
aircrack-ng: aircrack-ng (static WEP and WPA-PSK cracking), airdecap-ng
aircrack-ng: (decrypts WEP/WPA capture files), and some tools to handle
aircrack-ng: capture files (merge, convert, etc.).
aircrack-ng: 
aircrack-ng: 
aircrack-ng: Packaged for Zenwalk
END

# buildscript
install -d -m755 ${PKG}/usr/src/${PKG_NAME}-${VERSION}
install -m755 ${CWD}/${0} ${PKG}/usr/src/${PKG_NAME}-${VERSION}/build-${PKG_NAME}.sh

# Make the Zenwalk package
echo -n "making ${PKG_NAME} package..."
/sbin/makepkg -l y -c n ../${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.txz

# Calculate the md5sum of the Zenwalk package
echo "calculating dependencies and md5"
cd ${CWD}
md5sum ./${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.txz > ${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.md5
requiredbuilder -z ${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.txz > ${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.dep
echo "http://download.aircrack-ng.org/aircrack-ng-${VERSION_FILE}.tar.gz" > ${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.src
echo "http://zenwalk.pinguix.com/user-accounts/bip/EXTRA/n/${PKG_NAME}/build-${PKG_NAME}.sh" >> ${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.src
echo "Moving package files to upper directory"
mv -v ${PKG_NAME}-${VERSION}-${ARCH}-${ZEN_VER}.{txz,md5,dep,src} ${CWD}

# Cleanup
if [ "${CLEANUP}" = "1" ]; then
	rm -rf ${TMP}
	rm -rf ${PKG} 	
fi

# Finished!
echo "package: ${PKG_NAME} is finished."

exit 0
